@@ -86,7 +86,7 @@ class BaseService(object):
 
         for info in table_args:
             if info == "comment" :
-                return_table_name = info["comment"]
+                return_table_name = table_args["comment"]
                 break
             elif isinstance(info,dict):
                 print("info",info)
