@@ -14,12 +14,12 @@ class MyJwtConfig(object):
 
 # 定义签名密钥，用于校验jwt的有效、合法性
 class my_jwt():
-
+    default_config: MyJwtConfig = None
+    SECRET_KEY = ""
     def __init__(self, config: MyJwtConfig = None):
         if config:
-            self.SECRET_KEY = config.SECRET_KEY
-        else:
-            self.SECRET_KEY = "123"
+            self.default_config = config
+        self.SECRET_KEY = self.default_config.SECRET_KEY
 
     def create_token(self,name):
         '''基于jwt创建token的函数'''
